import { Controller, Get, Inject } from "@midwayjs/core";
import { RF } from "../response/CustomerResponse";
import { PartsService } from "../service/parts.service";
import { get } from "lodash";


@Controller('/home', { tagName: '首页' })
export class HomeController {
  @Inject()
  service: PartsService;

  @Get('/jtjs', { routerName: "集团介绍" })
  async jtjs() {
    const data = await this.service.jtjs();
    return RF.success(data);
  }

  @Get('/jtxw', { routerName: '集团新闻' })
  async jtxw() {
    const skip = 0;
    const limit = 3;
    const configList = [
      // 党建天地
      { channel_id: 186, part: 'djtd' },
      // 政策法规
      { channel_id: 187, part: 'zcfg' },
      // 招标采购
      { channel_id: 188, part: 'zbcg' },
      // 集团要闻
      { channel_id: 189, part: 'jtyw' },
    ]
    const returnData = {}
    for (const config of configList) {
      const { channel_id, part } = config;
      const { data: list } = await this.service.contentList(channel_id, {}, { skip, limit })
      // 重整理列表
      const newList = []
      for (const i of list) {
        const obj = {
          content_id: get(i, 'content_id'),
          title: get(i, 'ext.title'),
          date: get(i, 'ext.release_date'),
          brief: get(i, 'txt.txt'),
          url: get(i, 'ext.title_img')
        }
        newList.push(obj)
      }
      returnData[part] = newList;
    }
    return RF.success(returnData)
  }
}