import { Controller, Get, Inject, Param } from "@midwayjs/core";
import { RF } from "../response/CustomerResponse";
import { PartsService } from "../service/parts.service";
import { get } from "lodash";


@Controller('/jtjs', { tagName: '集团介绍' })
export class JtjsController {
  @Inject()
  service: PartsService;

  @Get('/jtjs', { routerName: '集团介绍' })
  async jtjs() {
    const channel_id = 175;
    const data = await this.service.channelDetail(channel_id);
    const newData = {
      title: get(data, 'channel_name'),
      txt: get(data, 'txt.txt')
    }
    return RF.success(newData);
  }

  @Get('/jgsz', { routerName: '机构设置' })
  async jgsz() {
    const data = await this.service.jgsz();
    return RF.success(data);
  }

  @Get('/gsjs', { routerName: '公司介绍' })
  async gsjs() {
    const configList = [
      //长春水务集团自来水有限公司
      { channel_id: 177, part: 'ccswjtzlsyxgs' },
      //长春水务集团源水有限责任公司
      { channel_id: 178, part: 'ccswjtysyxzrgs' },
      // 长春水务集团城市排水有限责任公司
      { channel_id: 179, part: 'ccswjtcspsyxzrgs' },
      // 长春市二次供水有限责任公司
      { channel_id: 180, part: 'ccsecgsyxzrgs' },
    ]
    const returnData = []
    for (const config of configList) {
      const { channel_id } = config;
      const data = await this.service.channelDetail(channel_id)
      if (data) {
        const newData = {
          channel_id,
          id: channel_id,
          title: get(data, 'channel_name'),
          txt: get(data, 'txt.txt')
        }
        returnData.push(newData);
      }
    }
    return RF.success(returnData)
  }
  @Get('/gsjs/:channel_id', { routerName: '公司介绍-单数据' })
  async gsjsDetail(@Param('channel_id') channel_id: string) {
    const data = await this.service.channelDetail(channel_id)
    let returnData = {};
    if (data) {
      const newData = {
        channel_id,
        title: get(data, 'title'),
        txt: get(data, 'txt.txt')
      }
      returnData = newData
    }
    return RF.success(returnData)
  }

  @Get('/scfm', { routerName: '三产风貌' })
  async scfm() {
    const configList = [
      //长春水务集团自来水有限公司
      { channel_id: 182, part: 'ccsgsgcgs' },
      //长春水务集团源水有限责任公司
      { channel_id: 183, part: 'cczlsgssbc' },
      // 长春水务集团城市排水有限责任公司
      { channel_id: 184, part: 'ccshhjzazgcyxgs' },
      // 长春市二次供水有限责任公司
      { channel_id: 185, part: 'ccshyjdsbazyxgs' },
    ]
    const returnData = {}
    for (const config of configList) {
      const { channel_id, part } = config;
      const data = await this.service.channelDetail(channel_id)
      if (data) returnData[part] = data;
    }
    return RF.success(returnData)
  }

  @Get('/scfm/:channel_id', { routerName: '三产风貌单数据详情' })
  async scfmDetail(@Param('channel_id') channel_id: string) {
    const data = await this.service.channelDetail(channel_id)
    return RF.success(data)
  }
}