import { Controller, Get, Inject, Param } from "@midwayjs/core";
import { PartsService } from "../service/parts.service";
import { Page, Query } from "../decorator/page.decorator";
import { RF } from "../response/CustomerResponse";
import { get } from "lodash";
import { PageViewService } from "../service/v2/pageView.service";

@Controller('/jtxw', { tagName: '集团新闻' })
export class JtxwController {
  @Inject()
  service: PartsService;
  @Inject()
  pageViewService: PageViewService;
  @Get('/list/:type', { routerName: '集团新闻列表' })
  async list(@Param('type') type: string, @Query() query: object, @Page() page: object) {
    const configList = [
      // 党建天地
      { channel_id: 186, type: 'djtd' },
      // 政策法规
      { channel_id: 187, type: 'zcfg' },
      // 招标采购
      { channel_id: 188, type: 'zbcg' },
      // 集团要闻
      { channel_id: 189, type: 'jtyw' },
    ]
    const config = configList.find(f => f.type === type)
    if (!config) return { data: null, total: 0 }
    const { channel_id } = config
    const { data, total } = await this.service.contentList(channel_id, query, page)
    const newList = []
    for (const i of data) {
      const newData = {
        content_id: get(i, 'content_id'),
        id: get(i, 'content_id'),
        title: get(i, 'ext.title'),
        brief: get(i, 'ext.description'),
        date: get(i, 'ext.release_date'),
        url: get(i, 'ext.title_img')
      }
      newList.push(newData)
    }
    return RF.success({ data: newList, total });
  }

  @Get('/detail/:content_id', { routerName: '集团新闻详情' })
  async detail(@Param('content_id') content_id: string) {
    const data: any = await this.service.contentDetail(content_id)
    // 增加浏览量,然后将浏览量放到返回数据中
    const views = await this.pageViewService.fetch(content_id)
    data.views = views;
    return RF.success(data);
  }
}
