import { Controller, Get, Inject, Param } from "@midwayjs/core";
import { RF } from "../response/CustomerResponse";
import { Page, Query } from "../decorator/page.decorator";
import { SearchService } from "../service/v2/search.service";
import { PartsService } from "../service/parts.service";
import { PageViewService } from "../service/v2/pageView.service";


@Controller('/search', { tagName: '全文检索' })
export class SearchController {
  @Inject()
  searchService: SearchService;
  @Inject()
  service: PartsService;
  @Inject()
  pageViewService: PageViewService;

  @Get('/query', { routerName: '全文检索列表查询' })
  async query(@Query() query: object, @Page() page: object) {
    const result = await this.searchService.textSearch(query, page)
    return RF.success(result);
  }

  @Get('/:content_id', { routerName: '全文检索详情' })
  async detail(@Param('content_id') content_id: string) {
    const data: any = await this.service.contentDetail(content_id)
    // 增加浏览量,然后将浏览量放到返回数据中
    const views = await this.pageViewService.fetch(content_id)
    data.views = views;
    return RF.success(data);
  }

}