import { Inject, Provide } from "@midwayjs/core";
import { CommonService } from "./frame/common.service";
import { get } from "lodash";

@Provide()
export class PartsService {
  @Inject()
  service: CommonService;
  /**
   * 根据编码查找channel对应的内容,主要是给-信息公开下的:
   * 获得用水: hdysz
   * 智慧水务: zhswz
   * 客户服务: khfwz
   * 用水常识: yscsz
   * 新区营商环境: xqyshj
   * 查找channel_id
   * @param code channel编码
   */
  async searchChannelIdByCode(code) {
    const channel = this.service.getModel('jc_channel')
    const channelData = await this.service.getOne(channel, { channel_path: code })
    if (!channelData) return
    const channel_id = get(channelData, 'channel_id')
    return channel_id;
  }



  /**集团介绍 */
  async jtjs() {
    const channel_id = 175;
    const channelTxt = this.service.getModel("jc_channel_txt")
    const data = await this.service.getOne(channelTxt, { channel_id })
    return data;
  }
  /**机构设置 */
  async jgsz() {
    const channel_id = 210;
    const channelTxt = this.service.getModel("jc_channel_txt")
    const data = await this.service.getOne(channelTxt, { channel_id })
    return data;
  }


  /**channel列表查询 */
  async channelList(channel_id, query = {}, page = {}, others = { order: { channel_id: 'DESC' } }) {
    const extModel = this.service.getModel("jc_channel_ext")
    const txtModel = this.service.getModel("jc_channel_txt")
    let { data, total } = await this.service.search(extModel, { channel_id, status: '2', ...query }, page, others)
    for (const ext of data) {
      const channel_id = get(ext, 'channel_id')
      const txt = await this.service.getOne(txtModel, { channel_id })
      if (txt) ext.txt = txt;
    }
    return { data, total }
  }

  /**channel详情查询 */
  async channelDetail(id) {
    const extModel = this.service.getModel("jc_channel_ext")
    const txtModel = this.service.getModel("jc_channel_txt")
    let ext = await this.service.getOne(extModel, { channel_id: id })
    const txt = await this.service.getOne(txtModel, { channel_id: id })
    ext = { ...ext, txt }
    return ext;
  }

  /**content列表查询 */
  async contentList(channel_id, query = {}, page = {}, others = { order: { content_id: 'DESC' } }) {
    const contentModel = this.service.getModel('jc_content')
    const extModel = this.service.getModel("jc_content_ext")
    const txtModel = this.service.getModel("jc_content_txt")
    let { data, total } = await this.service.search(contentModel, { channel_id, status: '2', ...query }, page, others)
    for (const i of data) {
      const content_id = get(i, 'content_id')
      const ext = await this.service.getOne(extModel, { content_id })
      if (ext) i.ext = ext;
      const txt = await this.service.getOne(txtModel, { content_id })
      if (txt) i.txt = txt;
    }
    return { data, total }
  }

  /**content详情查询 */
  async contentDetail(id) {
    const extModel = this.service.getModel("jc_content_ext")
    const txtModel = this.service.getModel("jc_content_txt")
    let ext = await this.service.getOne(extModel, { content_id: id })
    const txt = await this.service.getOne(txtModel, { content_id: id })
    ext = { ...ext, txt }
    return ext;
  }
}
